==> gottet_1.1.9.orig.tar.gz: gottet-1.1.9/translations/gottet_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>Board</name>
    <message>
        <source>Question</source>
        <translation>Soru</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>Şu anki oyun bitirilsin mi?</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Paused&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to resume playing.</source>
        <translation>&lt;big&gt;&lt;b&gt;Duraklatıldı&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Oynamaya devam etmek için tıklayın.</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Game Over!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to start a new game.</source>
        <translation>&lt;big&gt;&lt;b&gt;Oyun Bitti!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Yeni bir oyun başlatmak için tıklayın.</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Uygulama dilini seçin:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Sistem Dili&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Not</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Dil değişikliğinin etkin olması için lütfen bu uygulamayı yeniden başlatın.</translation>
    </message>
</context>
<context>
    <name>ScoreBoard</name>
    <message>
        <source>Gottet Scores</source>
        <translation>Gottet Skorları</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Seviye</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation>Çizgi</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Skor</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Tamam</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Gottet</source>
        <translation>Gottet</translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>Yeni bir oyun başlatmak için tıklayın.</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Oyun</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Yeni</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Duraklat</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Resume</source>
        <translation>Devam &amp;Ettir</translation>
    </message>
    <message>
        <source>&amp;Scores</source>
        <translation>&amp;Skorlar</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Çık</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Ayarlar</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Uydulama &amp;Dili...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Yardım</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Hakkında</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>&amp;Qt Hakkında</translation>
    </message>
    <message>
        <source>Next Piece</source>
        <translation>Sonraki Parça</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Seviye</translation>
    </message>
    <message>
        <source>Removed Lines</source>
        <translation>Yok Edilen Çizgiler</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Skor</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Hakkında</translation>
    </message>
    <message>
        <source>A tetris clone I made for my wife</source>
        <translation>Karım için yaptığım bir Tetris klonu</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott.</source>
        <translation>Telif hakları saklıdır &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>&lt;a href=%1&gt;GPL 3&lt;/a&gt; lisansı altında yayınlanmıştır</translation>
    </message>
</context>
</TS>

==> gottet_1.2.4.orig.tar.gz: gottet-1.2.4/translations/gottet_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>Board</name>
    <message>
        <source>Question</source>
        <translation>Soru</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>Şu anki oyun bitirilsin mi?</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Paused&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to resume playing.</source>
        <translation>&lt;big&gt;&lt;b&gt;Duraklatıldı&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Oynamaya devam etmek için tıklayın.</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Game Over!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to start a new game.</source>
        <translation>&lt;big&gt;&lt;b&gt;Oyun Bitti!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Yeni bir oyun başlatmak için tıklayın.</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Uygulama dilini seçin:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Sistem Dili&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Not</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Dil değişikliğinin etkin olması için lütfen bu uygulamayı yeniden başlatın.</translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>Level</source>
        <translation>Seviye</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation>Çizgi</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Skor</translation>
    </message>
    <message>
        <source>High Scores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rank</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>#%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Gottet</source>
        <translation>Gottet</translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>Yeni bir oyun başlatmak için tıklayın.</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Oyun</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Yeni</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Duraklat</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Scores</source>
        <translation>&amp;Skorlar</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Çık</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Ayarlar</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Uydulama &amp;Dili...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Yardım</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Hakkında</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>&amp;Qt Hakkında</translation>
    </message>
    <message>
        <source>Next Piece</source>
        <translation>Sonraki Parça</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Seviye</translation>
    </message>
    <message>
        <source>Removed Lines</source>
        <translation>Yok Edilen Çizgiler</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Skor</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Hakkında</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott.</source>
        <translation>Telif hakları saklıdır &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>&lt;a href=%1&gt;GPL 3&lt;/a&gt; lisansı altında yayınlanmıştır</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A simple falling blocks game</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
